@@ -29,8 +29,11 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <time.h>
 
-#include <gnome.h>
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
@@ -462,7 +465,7 @@ ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 							  _("Please install and activate NTP support in the system to enable "
 							    "synchronization of your local time server with "
-							    "internet time servers."));
+							    "Internet time servers."));
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 		return;
