@@ -28,10 +28,11 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glade/glade.h>
 
+#include <string.h>
 #include <time.h>
 #include <stdlib.h>
 
